# arvestust:admin:inlines
from .comment import CommentInline
from .file import FileInline
from .tag import TagInline
from .image import ImageInline
